@@ -77,7 +77,7 @@ def run(ctx: click.Context, versions: Tuple[str, ...], aggregate_output: Path, a
     envs = get_conda_env_set()
     target_envs = set(map(_get_env_name, versions))
     if not target_envs.issubset(envs):
-        raise click.BadParameter(f"Missing environments: {target_envs - envs}, please run \"slxpy build --setup-builder\" first.")
+        raise click.BadParameter(f"Missing environments: {target_envs - envs}, please run \"slxpy multi-build setup\" first.")
     for version in versions:  # Not using target_envs as set is not ordered.
         env_name = _get_env_name(version)
         click.secho(f"Building project in {env_name}.", fg="green")
