@@ -366,11 +366,18 @@ namespace slxpy::env::spec {
         PRESERVE_FILL,
         COMPRESS
     };
+    enum class ActionRepeatMode: uint8_t {
+        // Reward_Done
+        SUM_BREAK = 0
+    };
     static const char* IndexingModeNames[] = {
         "PRESERVE_EMPTY",
         "PRESERVE_FILL",
         "COMPRESS"
     };
+    static const char* ActionRepeatModeNames[] = {
+        "SUM_BREAK"
+    };
     class EnvSpec
     {
     public:
@@ -381,8 +388,10 @@ namespace slxpy::env::spec {
         IndexingMode indexing_mode = IndexingMode::PRESERVE_EMPTY;
         bool nondeterministic = false;
         bool auto_reset = false;
-        bool strict_reset = false;
+        bool strict_reset = true;
         bool need_render = false; // here?
+        size_t action_repeat = 0;
+        ActionRepeatMode action_repeat_mode = ActionRepeatMode::SUM_BREAK;
         pybind11::dict kwargs;
     public:
         std::string repr() {
@@ -396,8 +405,10 @@ namespace slxpy::env::spec {
     auto_reset={},
     strict_reset={},
     need_render={},
+    action_repeat={},
+    action_repeat_mode=<ActionRepeatMode.{}>,
     kwargs={}
-))--", id, reward_threshold, max_episode_steps, terminal_bonus_reward, IndexingModeNames[static_cast<uint8_t>(indexing_mode)], nondeterministic, auto_reset, strict_reset, need_render, std::string(pybind11::repr(kwargs)));
+))--", id, reward_threshold, max_episode_steps, terminal_bonus_reward, IndexingModeNames[static_cast<uint8_t>(indexing_mode)], nondeterministic, auto_reset, strict_reset, need_render, action_repeat, ActionRepeatModeNames[static_cast<uint8_t>(action_repeat_mode)], std::string(pybind11::repr(kwargs)));
         }
     };
 
@@ -408,6 +419,10 @@ namespace slxpy::env::spec {
             .value("PRESERVE_FILL", IndexingMode::PRESERVE_FILL)
             .value("COMPRESS", IndexingMode::COMPRESS);
 
+        pybind11::enum_<ActionRepeatMode> ActionRepeatMode_PB(s, "ActionRepeatMode");
+        ActionRepeatMode_PB
+            .value("SUM_BREAK", ActionRepeatMode::SUM_BREAK);
+
         pybind11::class_<EnvSpec> EnvSpec_PB(s, "EnvSpec");
         EnvSpec_PB
             .def(pybind11::init([] (
@@ -420,6 +435,8 @@ namespace slxpy::env::spec {
                     bool auto_reset,
                     bool strict_reset,
                     bool need_render,
+                    size_t action_repeat,
+                    ActionRepeatMode action_repeat_mode,
                     pybind11::kwargs kwargs
                 ) -> EnvSpec {
                     if (id.size() == 0) {
@@ -436,12 +453,15 @@ namespace slxpy::env::spec {
                         auto_reset,
                         strict_reset,
                         need_render,
+                        action_repeat,
+                        action_repeat_mode,
                         kwargs
                     };
                 }),
                 "id"_a, "reward_threshold"_a=std::nullopt, "max_episode_steps"_a=std::nullopt, "terminal_bonus_reward"_a=0.0,
                 "indexing_mode"_a=IndexingMode::PRESERVE_EMPTY,
-                "nondeterministic"_a=false, "auto_reset"_a=false, "strict_reset"_a=false, "need_render"_a=false
+                "nondeterministic"_a=false, "auto_reset"_a=false, "strict_reset"_a=true, "need_render"_a=false,
+                "action_repeat"_a=0, "action_repeat_mode"_a=ActionRepeatMode::SUM_BREAK
             )
             .def_readonly("id", &EnvSpec::id)
             .def_readonly("reward_threshold", &EnvSpec::reward_threshold)
@@ -452,6 +472,8 @@ namespace slxpy::env::spec {
             .def_readonly("auto_reset", &EnvSpec::auto_reset)
             .def_readonly("strict_reset", &EnvSpec::strict_reset)
             .def_readonly("need_render", &EnvSpec::need_render)
+            .def_readonly("action_repeat", &EnvSpec::action_repeat)
+            .def_readonly("action_repeat_mode", &EnvSpec::action_repeat_mode)
             .def_readonly("kwargs", &EnvSpec::kwargs)
             .def("__repr__", &EnvSpec::repr);
     }
